.. default-domain:: py
.. currentmodule:: fastnumbers

The Old "Safe" Functions
========================

These functions are deprecated as of :mod:`fastnumbers` version 0.3.0.
They are kept for backwards compatibility, but internally are now
identical to the "fast" functions. These "safe" functions will be
removed at some point in a future release.

:func:`~fastnumbers.safe_real`
------------------------------

.. autofunction:: safe_real

:func:`~fastnumbers.safe_float`
-------------------------------

.. autofunction:: safe_float

:func:`~fastnumbers.safe_int`
-----------------------------

.. autofunction:: safe_int

:func:`~fastnumbers.safe_forceint`
----------------------------------

.. autofunction:: safe_forceint
